# Automatically generated by get_definitionsALL.sql from database PRJ_TDCFDOKU.GRIB_PARAMETER@OFC1MIR.DWD.DE,do not edit! 2025-10-01 06:15
#paramId: 500000
#Pressure (S) (not reduced)
'500000' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500001
#Pressure
'500001' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500002
#Pressure Reduced to MSL
'500002' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500003
#Pressure Tendency (S)
'500003' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500004
#Geopotential (S)
'500004' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500005
#Geopotential (full lev)
'500005' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 110 ;
	}

#paramId: 500006
#Geopotential
'500006' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500007
#Geometric Height of the earths surface above sea level
'500007' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500008
#Geometric Height of the layer limits above sea level(NN)
'500008' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 109 ;
	}

#paramId: 500009
#Total Column Integrated Ozone
'500009' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500010
#Temperature (G)
'500010' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500011
#2m Temperature
'500011' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500012
#2m Temperature (AV)
'500012' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500013
#Climat. temperature, 2m Temperature
'500013' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500014
#Temperature
'500014' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500015
#Max 2m Temperature (i)
'500015' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500016
#Min 2m Temperature (i)
'500016' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500017
#2m Dew Point Temperature
'500017' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500018
#2m Dew Point Temperature (AV)
'500018' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500019
#Radar spectra (1)
'500019' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500020
#Wave spectra (1)
'500020' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500021
#Wave spectra (2)
'500021' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500022
#Wave spectra (3)
'500022' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500023
#Wind Direction (DD_10M)
'500023' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500024
#Wind Direction (DD)
'500024' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500025
#Wind speed (SP_10M)
'500025' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500026
#Wind speed (SP)
'500026' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500027
#U-Component of Wind
'500027' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500028
#U-Component of Wind
'500028' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500029
#V-Component of Wind
'500029' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500030
#V-Component of Wind
'500030' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500031
#Vertical Velocity (Pressure) ( omega=dp/dt )
'500031' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500032
#Vertical Velocity (Geometric) (w)
'500032' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500034
#Specific Humidity (2m)
'500034' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500035
#Specific Humidity
'500035' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500036
#2m Relative Humidity
'500036' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500037
#Relative Humidity
'500037' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500038
#Total column integrated water vapour
'500038' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 500039
#Evaporation (s)
'500039' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500040
#Total Column-Integrated Cloud Ice
'500040' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500041
#Total Precipitation (Accumulation)
'500041' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500042
#Large-Scale Precipitation (Accumulation)
'500042' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 62 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500043
#Convective Precipitation (Accumulation)
'500043' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500044
#Snow depth water equivalent
'500044' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500045
#Snow Depth
'500045' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 500046
#Total Cloud Cover
'500046' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500047
#Convective Cloud Cover
'500047' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500048
#Cloud Cover (800 hPa - Soil)
'500048' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500049
#Cloud Cover (400 - 800 hPa)
'500049' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500050
#Cloud Cover (0 - 400 hPa)
'500050' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500051
#Total Column-Integrated Cloud Water
'500051' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500052
#Convective Snowfall water equivalent (s)
'500052' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500053
#Large-Scale snowfall - water equivalent (Accumulation)
'500053' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500054
#Land Cover (1=land, 0=sea)
'500054' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 500055
#Surface Roughness length Surface Roughness
'500055' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500056
#Albedo (in short-wave)
'500056' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500057
#Albedo (in short-wave, average)
'500057' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500058
#Soil Temperature  ( 36 cm depth, vv=0h)
'500058' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 36 ;
	}

#paramId: 500059
#Soil Temperature (41 cm depth)
'500059' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 41 ;
	}

#paramId: 500060
#Soil Temperature
'500060' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 9 ;
	}

#paramId: 500061
#Soil Temperature
'500061' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500062
#Column-integrated Soil Moisture
'500062' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 100 ;
	 bottomLevel = 190 ;
	}

#paramId: 500063
#Column-integrated Soil Moisture (1) 0 -10 cm
'500063' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 10 ;
	}

#paramId: 500064
#Column-integrated Soil Moisture (2) 10-100cm
'500064' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 10 ;
	 bottomLevel = 100 ;
	}

#paramId: 500065
#Plant cover
'500065' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 500066
#Water Runoff
'500066' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 topLevel = 10 ;
	}

#paramId: 500068
#Water Runoff (s)
'500068' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 topLevel = 0 ;
	}

#paramId: 500069
#Sea Ice Cover ( 0= free, 1=cover)
'500069' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500070
#Sea Ice Thickness
'500070' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500071
#Significant height of combined wind waves and swell
'500071' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500072
#Direction of wind waves
'500072' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500073
#Significant height of wind waves
'500073' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500074
#Mean period of wind waves
'500074' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500075
#Mean direction of total swell
'500075' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500076
#Significant height of total swell
'500076' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500077
#Mean period of total swell
'500077' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 500078
#Net short wave radiation flux (at the surface)
'500078' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500079
#Net short wave radiation flux (at the surface)
'500079' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500080
#Net long wave radiation flux (m) (at the surface)
'500080' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500081
#Net long wave radiation flux
'500081' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500082
#Net short wave radiation flux (on the model top)
'500082' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500083
#Net short wave radiation flux
'500083' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	}

#paramId: 500084
#Net long wave radiation flux (m) (on the model top)
'500084' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500085
#Net long wave radiation flux
'500085' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	}

#paramId: 500086
#Latent Heat Net Flux (m)
'500086' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500087
#Sensible Heat Net Flux (m)
'500087' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500088
#Momentum Flux, U-Component (m)
'500088' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500089
#Momentum Flux, V-Component (m)
'500089' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500401
#Total Precipitation Difference
'500401' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 5 ;
	}

#paramId: 500404
#Total Precipitation (Accumulation) Initialisation
'500404' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500409
#Large-Scale snowfall - water equivalent (Accumulation) Initialisation
'500409' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500411
#Convective Snowfall water equivalent (s) Initialisation
'500411' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500416
#Evaporation (s) Initialisation
'500416' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500417
#Max 2m Temperature (i) Initialisation
'500417' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 2 ;
	}

#paramId: 500418
#Min 2m Temperature (i) Initialisation
'500418' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 2 ;
	}

#paramId: 500419
#Net short wave radiation flux
'500419' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500420
#Net long wave radiation flux
'500420' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500421
#Net short wave radiation flux (at the surface)
'500421' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500422
#Net long wave radiation flux
'500422' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500423
#Large-Scale snowfall - water equivalent (Accumulation) Initialisation
'500423' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500424
#Convective Snowfall water equivalent (s) Initialisation
'500424' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500425
#Total Precipitation (Accumulation) Initialisation
'500425' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500428
#Latent Heat Net Flux (m) Initialisation
'500428' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500429
#Sensible Heat Net Flux (m) Initialisation
'500429' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500430
#Momentum Flux, U-Component (m) Initialisation
'500430' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500431
#Momentum Flux, V-Component (m) Initialisation
'500431' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500475
#Water temperature
'500475' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 500477
#Absolute Vorticity
'500477' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500543
#vertical vorticity
'500543' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500544
#Potential vorticity
'500544' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500545
#Density
'500545' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500547
#Convective Precipitation (difference)
'500547' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 timeRangeIndicator = 5 ;
	}

#paramId: 500568
#Geopotential height
'500568' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500569
#Relative Divergenz
'500569' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500579
#Soil Temperature (layer)
'500579' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 112 ;
	}

#paramId: 500580
#Soil Moisture Content (0-7 cm)
'500580' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 7 ;
	}

#paramId: 500581
#Soil Moisture Content (7-50 cm)
'500581' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 7 ;
	 bottomLevel = 50 ;
	}

#paramId: 500582
#Max 2m Temperature (i) Initialisation
'500582' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 1 ;
	 level = 2 ;
	}

#paramId: 500583
#Min 2m Temperature (i) Initialisation
'500583' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 1 ;
	 level = 2 ;
	}

#paramId: 500588
#Snow melt
'500588' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500590
#ICAO Standard Atmosphere reference height
'500590' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500593
#Global radiation flux
'500593' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500642
#Lapse rate
'500642' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500905
#Specific Humidity (S)
'500905' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502317
#Latent Heat Net Flux - instant - at surface
'502317' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502318
#Sensible Heat Net Flux - instant - at surface
'502318' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502333
#salinity
'502333' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502334
#Stream function
'502334' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502335
#Velocity potential
'502335' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502350
#Temperature (G)
'502350' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502355
#Stream function
'502355' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502356
#Velocity potential
'502356' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502357
#Wind speed (SP)
'502357' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 502358
#Pressure
'502358' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 502359
#Potential vorticity
'502359' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 502360
#Potential vorticity
'502360' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 502361
#Geopotential
'502361' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 502362
#Max 2m Temperature
'502362' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502363
#Min 2m Temperature
'502363' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502364
#Temperature
'502364' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 502365
#U-Component of Wind
'502365' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 502366
#Pressure (S) (not reduced)
'502366' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502367
#V-Component of Wind
'502367' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 502368
#Specific Humidity
'502368' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 502369
#Vertical Velocity (Pressure) ( omega=dp/dt )
'502369' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 502370
#vertical vorticity
'502370' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 502371
#Sensible Heat Net Flux (m)
'502371' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502372
#Latent Heat Net Flux (m)
'502372' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502373
#Pressure Reduced to MSL
'502373' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 502374
#Relative Divergenz
'502374' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 502375
#Geopotential height
'502375' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 502376
#Relative Humidity
'502376' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 502377
#U-Component of Wind
'502377' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502378
#V-Component of Wind
'502378' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502379
#2m Temperature
'502379' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502381
#Land Cover (1=land, 0=sea)
'502381' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 502382
#Surface Roughness length Surface Roughness
'502382' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 502383
#Albedo (in short-wave, average)
'502383' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 502384
#Evaporation (s)
'502384' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502385
#Convective Cloud Cover
'502385' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 502386
#Cloud Cover (800 hPa - Soil)
'502386' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502387
#Cloud Cover (400 - 800 hPa)
'502387' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502388
#Cloud Cover (0 - 400 hPa)
'502388' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502389
#Plant cover
'502389' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 502390
#Water Runoff
'502390' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502391
#Total Column Integrated Ozone
'502391' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 502392
#Convective Snowfall water equivalent (s)
'502392' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 502393
#Large-Scale snowfall - water equivalent (Accumulation)
'502393' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 502394
#Large-Scale Precipitation
'502394' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 502395
#Total Column-Integrated Cloud Water
'502395' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 502396
#Virtual Temperature
'502396' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502397
#Virtual Temperature
'502397' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502398
#Virtual Temperature
'502398' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502399
#Brightness Temperature
'502399' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502400
#Boundary Layer Dissipitation
'502400' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502401
#Pressure Tendency
'502401' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 502402
#ICAO Standard Atmosphere reference height
'502402' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 502403
#Geometric Height
'502403' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502404
#Max Temperature
'502404' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502405
#Min Temperature
'502405' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502406
#Dew Point Temperature
'502406' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502407
#Dew point depression(or deficit)
'502407' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502408
#Lapse rate
'502408' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 502409
#Visibility
'502409' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 502410
#Radar spectra (1)
'502410' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 502411
#Radar spectra (2)
'502411' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502412
#Radar spectra (3)
'502412' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502413
#Parcel lifted index (to 500 hPa)
'502413' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502414
#Temperature anomaly
'502414' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502415
#Pressure anomaly
'502415' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502416
#Geopotential height anomaly
'502416' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502417
#Wave spectra (1)
'502417' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 502418
#Wave spectra (2)
'502418' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 502419
#Wave spectra (3)
'502419' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 502420
#Wind Direction (DD)
'502420' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 502421
#Sigma coordinate vertical velocity
'502421' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502422
#Absolute Vorticity
'502422' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 502423
#Absolute divergence
'502423' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502424
#Vertical u-component shear
'502424' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502425
#Vertical v-component shear
'502425' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502426
#Direction of current
'502426' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502427
#Speed of current
'502427' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502428
#U-component of current
'502428' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502429
#V-component of current
'502429' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502430
#Humidity mixing ratio
'502430' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502431
#Precipitable water
'502431' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 502432
#Vapour pressure
'502432' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502433
#Saturation deficit
'502433' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502434
#Precipitation rate
'502434' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502435
#Thunderstorm probability
'502435' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502436
#Convective precipitation (water)
'502436' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502437
#Snow fall rate water equivalent
'502437' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502438
#Mixed layer depth
'502438' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502439
#Transient thermocline depth
'502439' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502440
#Main thermocline depth
'502440' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502441
#Main thermocline depth
'502441' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502442
#Best lifted index (to 500 hPa)
'502442' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502443
#Water temperature
'502443' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 502444
#Deviation of sea-elbel from mean
'502444' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502445
#Column-integrated Soil Moisture
'502445' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502446
#salinity
'502446' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502447
#Density
'502447' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 502448
#Sea Ice Cover ( 0= free, 1=cover)
'502448' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 502449
#sea Ice Thickness
'502449' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 502450
#Direction of ice drift
'502450' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502451
#Speed of ice drift
'502451' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502452
#U-component of ice drift
'502452' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502453
#V-component of ice drift
'502453' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502454
#Ice growth rate
'502454' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502455
#Snow melt
'502455' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 502456
#Significant height of combined wind waves and swell
'502456' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 502457
#Direction of wind waves
'502457' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 502458
#Significant height of wind waves
'502458' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 502459
#Mean period of wind waves
'502459' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 502460
#Mean direction of total swell
'502460' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 502461
#Significant height of swell waves
'502461' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 502462
#Swell Mean Period
'502462' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 502465
#Secondary wave direction
'502465' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502466
#Secondary wave period
'502466' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502467
#Net short wave radiation flux (at the surface)
'502467' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502468
#Net long wave radiation flux (m) (at the surface)
'502468' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502469
#Net short wave radiation flux
'502469' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502470
#Net long-wave radiation flux(atmosph.top)
'502470' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502471
#Long wave radiation flux
'502471' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502472
#Short wave radiation flux
'502472' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502473
#Global radiation flux
'502473' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 502474
#Radiance (with respect to wave number)
'502474' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502475
#Radiance (with respect to wave length)
'502475' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502476
#Momentum Flux, U-Component (m)
'502476' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502477
#Momentum Flux, V-Component (m)
'502477' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502478
#Wind mixing energy
'502478' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502479
#Image data
'502479' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502480
#Geopotential height
'502480' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502481
#Soil Temperature
'502481' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502482
#Snow Depth water equivalent
'502482' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 502483
#Snow depth water equivalent
'502483' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 502484
#Total Cloud Cover
'502484' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 502485
#Total Precipitation (Accumulation)
'502485' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 502486
#Boundary Layer Dissipitation
'502486' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502487
#Sensible Heat Net Flux (m)
'502487' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502488
#Latent Heat Net Flux (m)
'502488' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502490
#Evaporation (s)
'502490' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502491
#Cloud Cover (800 hPa - Soil)
'502491' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502492
#Cloud Cover (400 - 800 hPa)
'502492' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502493
#Cloud Cover (0 - 400 hPa)
'502493' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502494
#Brightness Temperature
'502494' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502495
#Water Runoff
'502495' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502496
#Geometric Height
'502496' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502497
#Standard devation of height
'502497' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502498
#Standard devation of height
'502498' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502499
#Pseudo-adiabatic potential Temperature
'502499' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502500
#Pseudo-adiabatic potential Temperature
'502500' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502501
#Max Temperature
'502501' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502502
#Min Temperature
'502502' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502503
#Dew Point Temperature
'502503' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502504
#Dew point depression(or deficit)
'502504' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502506
#Radar spectra (2)
'502506' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502507
#Radar spectra (3)
'502507' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502508
#Parcel lifted index (to 500 hPa)
'502508' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502509
#Temperature anomaly
'502509' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502510
#Pressure anomaly
'502510' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502511
#Geopotential height anomaly
'502511' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502512
#Montgomery stream Function
'502512' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502513
#Montgomery stream Function
'502513' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502514
#Sigma coordinate vertical velocity
'502514' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502515
#Absolute divergence
'502515' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502516
#Vertical u-component shear
'502516' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502517
#Vertical v-component shear
'502517' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502518
#Direction of current
'502518' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502519
#Speed of current
'502519' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502520
#U-component of current
'502520' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502521
#V-component of current
'502521' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502522
#Humidity mixing ratio
'502522' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502523
#Vapour pressure
'502523' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502524
#Saturation deficit
'502524' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502525
#Precipitation rate
'502525' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502526
#Thunderstorm probability
'502526' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502527
#Convective precipitation (water)
'502527' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502528
#Snow fall rate water equivalent
'502528' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502529
#Mixed layer depth
'502529' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502530
#Transient thermocline depth
'502530' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502531
#Main thermocline depth
'502531' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502532
#Main thermocline depth
'502532' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502533
#Best lifted index (to 500 hPa)
'502533' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502534
#Deviation of sea-elbel from mean
'502534' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502535
#Column-integrated Soil Moisture
'502535' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502536
#Direction of ice drift
'502536' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502537
#Speed of ice drift
'502537' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502538
#U-component of ice drift
'502538' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502539
#V-component of ice drift
'502539' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502540
#Ice growth rate
'502540' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502542
#Snow melt
'502542' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 502545
#Secondary wave direction
'502545' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502546
#Secondary wave period
'502546' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502547
#Net short wave radiation flux (at the surface)
'502547' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502548
#Net long wave radiation flux (m) (at the surface)
'502548' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502549
#Net short wave radiation flux
'502549' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502550
#Net long-wave radiation flux(atmosph.top)
'502550' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502551
#Long wave radiation flux
'502551' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502552
#Short wave radiation flux
'502552' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502553
#Radiance (with respect to wave number)
'502553' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502554
#Radiance (with respect to wave length)
'502554' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502555
#Momentum Flux, U-Component (m)
'502555' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502556
#Momentum Flux, V-Component (m)
'502556' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502557
#Wind mixing energy
'502557' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502558
#Image data
'502558' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502559
#Geopotential height
'502559' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502560
#Soil Temperature
'502560' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502562
#Potential temperature
'502562' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502563
#Potential temperature
'502563' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502564
#Wind speed (SP)
'502564' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 502565
#Pressure
'502565' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 502566
#Max 2m Temperature
'502566' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502567
#Min 2m Temperature
'502567' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502568
#Geopotential
'502568' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 502569
#Temperature
'502569' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 502570
#U-Component of Wind
'502570' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 502571
#V-Component of Wind
'502571' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 502572
#Specific Humidity
'502572' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 502573
#Pressure (S) (not reduced)
'502573' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502574
#Vertical Velocity (Pressure) ( omega=dp/dt )
'502574' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 502575
#vertical vorticity
'502575' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 502576
#Boundary Layer Dissipitation
'502576' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502577
#Sensible Heat Net Flux (m)
'502577' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502578
#Latent Heat Net Flux (m)
'502578' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502579
#Pressure Reduced to MSL
'502579' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 502581
#Geopotential height
'502581' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 502582
#Relative Humidity
'502582' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 502583
#U-Component of Wind
'502583' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502584
#V-Component of Wind
'502584' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502585
#2m Temperature
'502585' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502587
#Relative Divergenz
'502587' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 502588
#Land Cover (1=land, 0=sea)
'502588' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 502589
#Surface Roughness length Surface Roughness
'502589' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 502590
#Albedo (in short-wave, average)
'502590' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 502591
#Evaporation (s)
'502591' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502592
#Convective Cloud Cover
'502592' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 502593
#Cloud Cover (800 hPa - Soil)
'502593' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502594
#Cloud Cover (400 - 800 hPa)
'502594' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502595
#Cloud Cover (0 - 400 hPa)
'502595' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502596
#Brightness Temperature
'502596' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502597
#Plant cover
'502597' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 502598
#Water Runoff
'502598' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502599
#Total Column Integrated Ozone
'502599' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 502600
#Convective Snowfall water equivalent (s)
'502600' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 502601
#Large-Scale snowfall - water equivalent (Accumulation)
'502601' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 502602
#Large-Scale Precipitation
'502602' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 502603
#Total Column-Integrated Cloud Water
'502603' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 502604
#Pressure Tendency
'502604' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 502605
#ICAO Standard Atmosphere reference height
'502605' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 502606
#Geometric Height
'502606' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502607
#Standard devation of height
'502607' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502608
#Pseudo-adiabatic potential Temperature
'502608' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502609
#Max Temperature
'502609' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502610
#Min Temperature
'502610' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502611
#Dew Point Temperature
'502611' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502612
#Dew point depression(or deficit)
'502612' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502613
#Lapse rate
'502613' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 502614
#Visibility
'502614' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 502615
#Radar spectra (1)
'502615' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 502616
#Radar spectra (2)
'502616' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502617
#Radar spectra (3)
'502617' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502618
#Parcel lifted index (to 500 hPa)
'502618' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502619
#Temperature anomaly
'502619' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502620
#Pressure anomaly
'502620' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502621
#Geopotential height anomaly
'502621' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502622
#Wave spectra (1)
'502622' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 502623
#Wave spectra (2)
'502623' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 502624
#Wave spectra (3)
'502624' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 502625
#Wind Direction (DD)
'502625' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 502626
#Montgomery stream Function
'502626' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502627
#Sigma coordinate vertical velocity
'502627' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502628
#Absolute Vorticity
'502628' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 502629
#Absolute divergence
'502629' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502630
#Vertical u-component shear
'502630' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502631
#Vertical v-component shear
'502631' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502632
#Direction of current
'502632' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502633
#Speed of current
'502633' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502634
#U-component of current
'502634' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502635
#V-component of current
'502635' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502636
#Humidity mixing ratio
'502636' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502637
#Precipitable water
'502637' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 502638
#Vapour pressure
'502638' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502639
#Saturation deficit
'502639' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502640
#Precipitation rate
'502640' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502641
#Thunderstorm probability
'502641' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502642
#Convective precipitation (water)
'502642' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502643
#Snow fall rate water equivalent
'502643' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502644
#Mixed layer depth
'502644' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502645
#Transient thermocline depth
'502645' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502646
#Main thermocline depth
'502646' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502647
#Main thermocline depth
'502647' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502648
#Best lifted index (to 500 hPa)
'502648' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502649
#Water temperature
'502649' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 502650
#Deviation of sea-elbel from mean
'502650' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502651
#Column-integrated Soil Moisture
'502651' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502652
#salinity
'502652' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502653
#Density
'502653' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 502654
#Sea Ice Cover ( 0= free, 1=cover)
'502654' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 502655
#sea Ice Thickness
'502655' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 502656
#Direction of ice drift
'502656' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502657
#Speed of ice drift
'502657' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502658
#U-component of ice drift
'502658' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502659
#V-component of ice drift
'502659' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502660
#Ice growth rate
'502660' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502662
#Significant height of combined wind waves and swell
'502662' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 502663
#Direction of wind waves
'502663' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 502664
#Significant height of wind waves
'502664' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 502665
#Mean period of wind waves
'502665' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 502666
#Mean direction of total swell
'502666' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 502667
#Significant height of swell waves
'502667' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 502668
#Swell Mean Period
'502668' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 502671
#Secondary wave direction
'502671' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502672
#Secondary wave period
'502672' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502673
#Net short wave radiation flux (at the surface)
'502673' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502674
#Net long wave radiation flux (m) (at the surface)
'502674' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502675
#Net short wave radiation flux
'502675' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502676
#Net long-wave radiation flux(atmosph.top)
'502676' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502677
#Long wave radiation flux
'502677' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502678
#Short wave radiation flux
'502678' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502679
#Global radiation flux
'502679' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 502680
#Radiance (with respect to wave number)
'502680' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502681
#Radiance (with respect to wave length)
'502681' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502682
#Momentum Flux, U-Component (m)
'502682' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502683
#Momentum Flux, V-Component (m)
'502683' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502684
#Wind mixing energy
'502684' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502685
#Image data
'502685' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502686
#Geopotential height
'502686' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502687
#Column-integrated Soil Moisture
'502687' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502688
#Soil Temperature
'502688' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502689
#Snow Depth water equivalent
'502689' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 502690
#Snow depth water equivalent
'502690' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 502691
#Total Cloud Cover
'502691' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 502692
#Total Precipitation (Accumulation)
'502692' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 502693
#Potential temperature
'502693' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502694
#Ice divergence
'502694' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502695
#Ice divergence
'502695' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502696
#Ice divergence
'502696' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502697
#Velocity potential
'502697' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502750
#Stream function
'502750' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502946
#Visibility
'502946' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 503063
#Momentum Flux, U-Component (m)
'503063' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503064
#Momentum Flux, V-Component (m)
'503064' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503098
#Vertical Velocity (Geometric) (w)
'503098' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 503099
#Fog_fraction
'503099' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 503100
#accumulated_convective_rain
'503100' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 503101
#cloud_fraction_below_1000ft
'503101' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 503103
#Lowest_cloud_base_height
'503103' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 503104
#wet_bulb_freezing_level_ht
'503104' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 503105
#freezing_level_ICAO_height
'503105' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 162 ;
	}

#paramId: 503140
#orography
'503140' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 503141
#wind_gust_10m
'503141' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 503350
#relative vorticity
'503350' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500090
#Photosynthetically active radiation (m) (at the surface)
'500090' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500091
#Photosynthetically active radiation
'500091' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500092
#Solar radiation heating rate
'500092' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500093
#Thermal radiation heating rate
'500093' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500094
#Latent heat flux from bare soil
'500094' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 18 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500095
#Latent heat flux from plants
'500095' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 19 ;
	 indicatorOfTypeOfLevel = 111 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500096
#Sunshine duration in h
'500096' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 20 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500097
#Stomatal Resistance
'500097' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 21 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500098
#Cloud cover
'500098' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500099
#Non-Convective Cloud Cover, grid scale
'500099' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500100
#Cloud Mixing Ratio
'500100' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500101
#Cloud Ice Mixing Ratio
'500101' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500102
#Rain mixing ratio
'500102' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500103
#Snow mixing ratio
'500103' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 500104
#Total column integrated rain
'500104' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 500105
#Total column integrated snow
'500105' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 500106
#Grauple
'500106' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500107
#Total column integrated grauple
'500107' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500108
#Total Column integrated water (all components incl. precipitation)
'500108' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500109
#vertical integral of divergence of total water content (s)
'500109' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500110
#subgrid scale cloud water
'500110' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500111
#subgridscale cloud ice
'500111' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500112
#cloud cover CH (0..8)
'500112' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500113
#cloud cover CM (0..8)
'500113' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500114
#cloud cover CL (0..8)
'500114' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 500115
#cloud base above msl, shallow convection
'500115' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 2 ;
	}

#paramId: 500116
#Cloud top above msl, shallow convection
'500116' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 59 ;
	 indicatorOfTypeOfLevel = 3 ;
	}

#paramId: 500117
#specific cloud water content, convective cloud
'500117' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500118
#Height of Convective Cloud Base above msl
'500118' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 2 ;
	}

#paramId: 500119
#Height of Convective Cloud Top above msl
'500119' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 3 ;
	}

#paramId: 500120
#base index (vertical level) of main convective cloud (i)
'500120' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500121
#top index (vertical level) of main convective cloud (i)
'500121' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500122
#Temperature tendency due to convection
'500122' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500123
#Specific humidity tendency due to convection
'500123' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500124
#zonal wind tendency due to convection
'500124' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500125
#meridional wind tendency due to convection
'500125' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500126
#Height of top of dry convection above MSL
'500126' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500127
#Height of 0 degree Celsius isotherm above msl
'500127' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 4 ;
	}

#paramId: 500128
#Height of snow fall limit above MSL
'500128' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 4 ;
	}

#paramId: 500129
#Tendency of specific cloud liquid water content due to convection
'500129' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 500130
#tendency of  specific cloud ice content due to convection
'500130' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500131
#Specific content of precipitation particles (needed for water loading)
'500131' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500132
#Large scale rain rate
'500132' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500133
#Large scale snowfall rate water equivalent
'500133' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500134
#Large scale rain (Accumulation)
'500134' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500135
#Convective rain rate
'500135' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500136
#Convective snowfall rate water equivalent
'500136' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500137
#Convective rain
'500137' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500138
#rain amount, grid-scale plus convective
'500138' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500139
#snow amount, grid-scale plus convective
'500139' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500140
#Temperature tendency due to grid scale precipation
'500140' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500141
#Specific humidity tendency due to grid scale precipitation
'500141' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500142
#tendency of specific cloud liquid water content due to grid scale precipitation
'500142' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500143
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'500143' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 500144
#tendency of specific cloud ice content due to grid scale precipitation
'500144' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 130 ;
	}

#paramId: 500145
#Graupel (snow pellets) precipitation rate
'500145' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500146
#Graupel (snow pellets) precipitation (Accumulation)
'500146' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500147
#Snow density
'500147' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500148
#Pressure perturbation
'500148' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500149
#supercell detection index 1 (rot. up+down drafts)
'500149' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 141 ;
	}

#paramId: 500150
#supercell detection index 2 (only rot. up drafts)
'500150' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 142 ;
	}

#paramId: 500151
#Convective Available Potential Energy, most unstable
'500151' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 143 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500152
#Convective Inhibition, most unstable
'500152' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 144 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500153
#Convective Available Potential Energy, mean layer
'500153' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 145 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500154
#Convective Inhibition, mean layer
'500154' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 146 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500155
#Convective turbulent kinetic enery
'500155' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 147 ;
	}

#paramId: 500156
#Tendency of turbulent kinetic energy
'500156' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 500157
#Kinetic Energy
'500157' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 500158
#Turbulent Kinetic Energy
'500158' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 500159
#Turbulent diffusioncoefficient for momentum
'500159' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 153 ;
	}

#paramId: 500160
#Turbulent diffusion coefficient for heat (and moisture)
'500160' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500161
#Turbulent transfer coefficient for impulse
'500161' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 170 ;
	}

#paramId: 500162
#Turbulent transfer coefficient for heat (and Moisture)
'500162' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 171 ;
	}

#paramId: 500163
#mixed layer depth
'500163' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 173 ;
	}

#paramId: 500164
#maximum Wind 10m
'500164' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500166
#Soil Temperature (multilayer model)
'500166' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 197 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500167
#Column-integrated Soil Moisture (multilayers)
'500167' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500168
#soil ice content (multilayers)
'500168' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500169
#Plant Canopy Surface Water
'500169' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500170
#Snow temperature (top of snow)
'500170' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500171
#Minimal Stomatal Resistance
'500171' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500172
#Sea Ice Temperature
'500172' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500173
#Base reflectivity
'500173' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500174
#Base reflectivity
'500174' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 110 ;
	}

#paramId: 500175
#Base reflectivity (cmax)
'500175' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	}

#paramId: 500176
#solution of 2-d Helmholtz equations - needed for restart
'500176' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500177
#Effective transmissivity of solar radiation
'500177' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500178
#sum of contributions to evaporation
'500178' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500179
#total transpiration from all soil layers
'500179' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 237 ;
	}

#paramId: 500180
#total forcing at soil surface
'500180' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 238 ;
	}

#paramId: 500181
#residuum of soil moisture
'500181' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 239 ;
	}

#paramId: 500182
#Massflux at convective cloud base
'500182' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 240 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500183
#Convective Available Potential Energy
'500183' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500184
#moisture convergence for Kuo-type closure
'500184' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500185
#Total Wave Direction
'500185' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500187
#Peak period of total swell
'500187' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500189
#Swell peak period
'500189' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500190
#Total wave peak period
'500190' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500191
#Total wave mean period
'500191' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500192
#Total Tm1 period
'500192' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500193
#Total Tm2 period
'500193' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500194
#Total directional spread
'500194' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500195
#analysis error(standard deviation), geopotential(gpm)
'500195' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500196
#analysis error(standard deviation), u-comp. of wind
'500196' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500197
#analysis error(standard deviation), v-comp. of wind
'500197' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500198
#zonal wind tendency due to subgrid scale oro.
'500198' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500199
#meridional wind tendency due to subgrid scale oro.
'500199' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 500200
#Standard deviation of sub-grid scale orography
'500200' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 500201
#Anisotropy of sub-gridscale orography
'500201' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 500202
#Angle of sub-gridscale orography
'500202' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 500203
#Slope of sub-gridscale orography
'500203' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 500204
#surface emissivity
'500204' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 500205
#soil type of grid (1...9, local soilType.table)
'500205' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500206
#Leaf area index
'500206' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500207
#root depth of vegetation
'500207' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 500208
#height of ozone maximum (climatological)
'500208' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 500209
#vertically integrated ozone content (climatological)
'500209' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500210
#Plant covering degree in the vegetation phase
'500210' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 500211
#Plant covering degree in the quiescent phas
'500211' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 500212
#Max Leaf area index
'500212' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500213
#Min Leaf area index
'500213' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500214
#Orographie + Land-Meer-Verteilung
'500214' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500215
#variance of soil moisture content (0-10)
'500215' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	}

#paramId: 500216
#variance of soil moisture content (10-100)
'500216' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 112 ;
	}

#paramId: 500217
#evergreen forest
'500217' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500218
#deciduous forest
'500218' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500219
#normalized differential vegetation index
'500219' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 77 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500220
#normalized differential vegetation index (NDVI)
'500220' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500221
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'500221' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500222
#current ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'500222' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500223
#Total sulfate aerosol
'500223' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500224
#Total sulfate aerosol (12M)
'500224' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500225
#Total soil dust aerosol (climatology)
'500225' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 500226
#Total soil dust aerosol (climatology,12M)
'500226' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500227
#Organic aerosol
'500227' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500228
#Organic aerosol (12M)
'500228' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500229
#Black carbon aerosol
'500229' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500230
#Black carbon aerosol (12M)
'500230' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500231
#Sea salt aerosol
'500231' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500232
#Sea salt aerosol (12M)
'500232' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500233
#tendency of specific humidity
'500233' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500234
#water vapor flux
'500234' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500235
#Coriolis parameter
'500235' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500236
#geographical latitude
'500236' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500237
#geographical longitude
'500237' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500239
#Delay of the GPS signal trough the (total) atm.
'500239' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 500240
#Delay of the GPS signal trough wet atmos.
'500240' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500241
#Delay of the GPS signal trough dry atmos.
'500241' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500242
#Ozone Mixing Ratio
'500242' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 180 ;
	}

#paramId: 500243
#Air concentration of Ruthenium 103
'500243' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500244
#Ru103 - dry deposition
'500244' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 195 ;
	}

#paramId: 500245
#Ru103 - wet deposition
'500245' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500246
#Air concentration of Strontium 90
'500246' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500247
#Sr90 - dry deposition
'500247' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500248
#Sr90 - wet deposition
'500248' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500249
#Air concentration of Iodine 131 aerosol
'500249' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500250
#I131 - dry deposition
'500250' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 201 ;
	}

#paramId: 500251
#I131 - wet deposition
'500251' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 202 ;
	}

#paramId: 500252
#Air concentration of Caesium 137
'500252' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500253
#Cs137 - dry deposition
'500253' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500255
#Air concentration of Tellurium 132
'500255' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 206 ;
	}

#paramId: 500256
#Te132 - dry deposition
'500256' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 500257
#Te132 - wet deposition
'500257' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 208 ;
	}

#paramId: 500258
#Air concentration of Zirconium 95
'500258' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 209 ;
	}

#paramId: 500259
#Zr95 - dry deposition
'500259' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 210 ;
	}

#paramId: 500260
#Zr95 - wet deposition
'500260' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500261
#Air concentration of Krypton 85
'500261' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500262
#Kr85 - dry deposition
'500262' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500263
#Kr85 - wet deposition
'500263' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 214 ;
	}

#paramId: 500264
#TRACER - concentration
'500264' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500265
#TRACER - dry deposition
'500265' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 216 ;
	}

#paramId: 500266
#TRACER - wet deposition
'500266' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 217 ;
	}

#paramId: 500267
#Air concentration of Xenon 133
'500267' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 218 ;
	}

#paramId: 500268
#Xe133 - dry deposition
'500268' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 219 ;
	}

#paramId: 500269
#Xe133 - wet deposition
'500269' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 220 ;
	}

#paramId: 500270
#Air concentration of Iodine 131 elementary gaseous
'500270' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 221 ;
	}

#paramId: 500271
#I131g - dry deposition
'500271' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 222 ;
	}

#paramId: 500272
#I131g - wet deposition
'500272' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 223 ;
	}

#paramId: 500273
#Air concentration of Iodine 131 organic bounded
'500273' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 224 ;
	}

#paramId: 500274
#I131o - dry deposition
'500274' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 225 ;
	}

#paramId: 500275
#I131o - wet deposition
'500275' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 226 ;
	}

#paramId: 500276
#Air concentration of Barium 140
'500276' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 227 ;
	}

#paramId: 500277
#Ba140 - dry deposition
'500277' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 228 ;
	}

#paramId: 500278
#Ba140 - wet deposition
'500278' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 229 ;
	}

#paramId: 500279
#u-momentum flux due to SSO-effects
'500279' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500280
#u-momentum flux due to SSO-effects
'500280' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500281
#v-momentum flux due to SSO-effects (average)
'500281' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500282
#v-momentum flux due to SSO-effects
'500282' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500283
#Gravity wave dissipation (initialisation)
'500283' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500284
#Gravity wave dissipation (vertical integral)
'500284' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500285
#UV Index, clouded sky, maximum
'500285' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 248 ;
	}

#paramId: 500286
#Vertical speed shear
'500286' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500287
#storm relative helicity
'500287' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500288
#Absolute vorticity advection
'500288' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500289
#Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ,tab)
'500289' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500290
#Hoehe der Konvektionsuntergrenze ueber Grund
'500290' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500291
#Hoehe der Konvektionsuntergrenze ueber nn
'500291' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 94 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500292
#weather interpretation (WMO)
'500292' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500293
#geostrophische Vorticityadvektion
'500293' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500294
#geostrophische Schichtdickenadvektion
'500294' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500295
#Schichtdickenadvektion
'500295' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 107 ;
	}

#paramId: 500296
#Winddivergenz
'500296' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 500297
#Q-Vektor senkrecht zu den Isothermen
'500297' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500298
#Isentrope potentielle Vorticity
'500298' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 100 ;
	}

#paramId: 500299
#Wind X-Komponente auf isentropen Flaechen
'500299' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500300
#Wind Y-Komponente auf isentropen Flaechen
'500300' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500301
#Druck einer isentropen Flaeche
'500301' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 100 ;
	}

#paramId: 500302
#KO index
'500302' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 500303
#Aequivalentpotentielle Temperatur
'500303' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500304
#Ceiling
'500304' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500305
#Icing Grade (1=LGT,2=MOD,3=SEV)
'500305' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500306
#modified cloud depth for media
'500306' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500307
#modified cloud cover for media
'500307' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500308
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'500308' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500309
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'500309' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500310
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'500310' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500311
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'500311' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500312
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'500312' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500313
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'500313' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500314
#Monthly Mean of RMS of difference FG-AN of geopotential
'500314' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500315
#Monthly Mean of RMS of difference IA-AN of geopotential
'500315' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500316
#Monthly Mean of RMS of difference FG-AN of relative humidity
'500316' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500317
#Monthly Mean of RMS of difference IA-AN of relative humidity
'500317' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500318
#Monthly Mean of RMS of difference FG-AN of temperature
'500318' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500319
#Monthly Mean of RMS of difference IA-AN of temperature
'500319' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500320
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'500320' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500321
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'500321' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500322
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'500322' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500323
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'500323' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500324
#Synth. Sat. brightness temperature cloudy
'500324' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500325
#Synth. Sat. brightness temperature clear sky
'500325' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500326
#Synth. Sat. radiance cloudy
'500326' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500327
#Synth. Sat. radiance clear sky
'500327' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500328
#Synth. Sat. brightness temperature cloudy
'500328' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500329
#Synth. Sat. brightness temperature clear sky
'500329' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500330
#Synth. Sat. radiance cloudy
'500330' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500331
#Synth. Sat. radiance clear sky
'500331' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500332
#Synth. Sat. brightness temperature cloudy
'500332' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500333
#Synth. Sat. brightness temperature cloudy
'500333' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500334
#Synth. Sat. brightness temperature clear sky
'500334' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500335
#Synth. Sat. brightness temperature clear sky
'500335' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500336
#Synth. Sat. radiance cloudy
'500336' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500337
#Synth. Sat. radiance cloudy
'500337' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500338
#Synth. Sat. radiance clear sky
'500338' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500339
#Synth. Sat. radiance clear sky
'500339' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500340
#Synth. Sat. brightness temperature cloudy
'500340' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500341
#Synth. Sat. brightness temperature cloudy
'500341' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500342
#Synth. Sat. brightness temperature cloudy
'500342' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500343
#Synth. Sat. brightness temperature cloudy
'500343' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500344
#Synth. Sat. brightness temperature cloudy
'500344' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500345
#Synth. Sat. brightness temperature cloudy
'500345' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500346
#Synth. Sat. brightness temperature cloudy
'500346' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500347
#Synth. Sat. brightness temperature cloudy
'500347' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500348
#Synth. Sat. brightness temperature clear sky
'500348' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500349
#Synth. Sat. brightness temperature clear sky
'500349' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500350
#Synth. Sat. brightness temperature clear sky
'500350' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500351
#Synth. Sat. brightness temperature clear sky
'500351' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500352
#Synth. Sat. brightness temperature clear sky
'500352' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500353
#Synth. Sat. brightness temperature clear sky
'500353' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500354
#Synth. Sat. brightness temperature clear sky
'500354' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500355
#Synth. Sat. brightness temperature clear sky
'500355' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500356
#Synth. Sat. radiance cloudy
'500356' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500357
#Synth. Sat. radiance cloudy
'500357' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500358
#Synth. Sat. radiance cloudy
'500358' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500359
#Synth. Sat. radiance cloudy
'500359' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500360
#Synth. Sat. radiance cloudy
'500360' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500361
#Synth. Sat. radiance cloudy
'500361' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500362
#Synth. Sat. radiance cloudy
'500362' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500363
#Synth. Sat. radiance cloudy
'500363' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500364
#Synth. Sat. radiance clear sky
'500364' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500365
#Synth. Sat. radiance clear sky
'500365' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500366
#Synth. Sat. radiance clear sky
'500366' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500367
#Synth. Sat. radiance clear sky
'500367' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500368
#Synth. Sat. radiance clear sky
'500368' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500369
#Synth. Sat. radiance clear sky
'500369' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500370
#Synth. Sat. radiance clear sky
'500370' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500371
#Synth. Sat. radiance clear sky
'500371' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500372
#smoothed forecast, temperature
'500372' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500373
#smoothed forecast, maximum temp.
'500373' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500374
#smoothed forecast, minimum temp.
'500374' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500375
#smoothed forecast, dew point temp.
'500375' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500376
#smoothed forecast, u comp. of wind
'500376' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500377
#smoothed forecast, v comp. of wind
'500377' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500378
#smoothed forecast, total precipitation (Accumulation)
'500378' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500379
#smoothed forecast, total cloud cover
'500379' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500380
#smoothed forecast, cloud cover low
'500380' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500381
#smoothed forecast, cloud cover medium
'500381' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500382
#smoothed forecast, cloud cover high
'500382' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500383
#smoothed forecast, large-scale snowfall
'500383' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500384
#smoothed forecast, soil temperature
'500384' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}

#paramId: 500385
#smoothed forecast, wind speed (gust)
'500385' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500386
#calibrated forecast, total precipitation  (Accumulation)
'500386' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500387
#calibrated forecast, large-scale snowfall
'500387' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500388
#calibrated forecast, wind speed (gust)
'500388' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500402
#Max 2m Temperature long periods > h
'500402' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 55 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500403
#Min 2m Temperature long periods > h
'500403' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 56 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500408
#Large scale rain (Accumulation) Initialisation
'500408' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500410
#Convective rain Initialisation
'500410' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500412
#maximum Wind 10m Initialisation
'500412' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 10 ;
	}

#paramId: 500432
#Photosynthetically active radiation
'500432' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500433
#Large scale rain (Accumulation) Initialisation
'500433' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500434
#Convective rain Initialisation
'500434' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500436
#Graupel (snow pellets) precipitation (Initialisation)
'500436' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500437
#Probability of 1h total precipitation >= 10mm
'500437' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500438
#Probability of 1h total precipitation >= 25mm
'500438' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500439
#Probability of 6h total precipitation >= 20mm
'500439' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500440
#Probability of 6h total precipitation >= 35mm
'500440' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500441
#Probability of 12h total precipitation >= 25mm
'500441' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500442
#Probability of 12h total precipitation >= 40mm
'500442' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500443
#Probability of 12h total precipitation >= 70mm
'500443' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500444
#Probability of 6h accumulated snow >=0.5cm
'500444' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500445
#Probability of 6h accumulated snow >= 5cm
'500445' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500446
#Probability of 6h accumulated snow >= 10cm
'500446' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500447
#Probability of 12h accumulated snow >=0.5cm
'500447' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500448
#Probability of 12h accumulated snow >= 10cm
'500448' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500449
#Probability of 12h accumulated snow >= 15cm
'500449' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500450
#Probability of 12h accumulated snow >= 25cm
'500450' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 500451
#Probability of 1h maximum wind gust speed >= 14m/s
'500451' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500452
#Probability of 1h maximum wind gust speed >= 18m/s
'500452' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500453
#Probability of 1h maximum wind gust speed >= 25m/s
'500453' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 136 ;
	}

#paramId: 500454
#Probability of 1h maximum wind gust speed >= 29m/s
'500454' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 137 ;
	}

#paramId: 500455
#Probability of 1h maximum wind gust speed >= 33m/s
'500455' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 500456
#Probability of 1h maximum wind gust speed >= 39m/s
'500456' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500457
#Probability of black ice during 1h
'500457' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500458
#Probability of thunderstorm during 1h
'500458' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500459
#Probability of heavy thunderstorm during 1h
'500459' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500460
#Probability of severe thunderstorm during 1h
'500460' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500461
#Probability of snowdrift during 12h
'500461' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500462
#Probability of strong snowdrift during 12h
'500462' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500463
#Probability of temperature < 0 deg C during 1h
'500463' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500464
#Probability of temperature <= -10 deg C during 6h
'500464' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500465
#UV Index, clear sky; corrected for albedo, aerosol and altitude
'500465' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 240 ;
	}

#paramId: 500466
#Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol
'500466' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500467
#UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds
'500467' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 242 ;
	}

#paramId: 500468
#UV Index, clear sky, maximum
'500468' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500469
#Total ozone
'500469' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 247 ;
	}

#paramId: 500471
#Time of maximum of UV Index, clouded
'500471' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 249 ;
	}

#paramId: 500472
#Konvektionsart (0..4)
'500472' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500473
#perceived temperature
'500473' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 500476
#Water temperature in C
'500476' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500478
#probability to perceive sultriness
'500478' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500479
#value of isolation of clothes
'500479' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500480
#Downward direct short wave radiation flux at surface (mean over forecast time)
'500480' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500481
#Downward diffusive short wave radiation flux
'500481' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500482
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'500482' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500486
#vertical integral of divergence of total water content (s)
'500486' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500487
#Downward direct short wave radiation flux at surface (mean over forecast time) Initialisation
'500487' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500488
#Downward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'500488' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500489
#Upward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'500489' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500490
#Water Fraction
'500490' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 500491
#Lake depth
'500491' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 500492
#Wind fetch
'500492' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 500493
#Attenuation coefficient of water with respect to solar radiation
'500493' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500494
#Depth of thermally active layer of bottom sediment
'500494' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500495
#Temperature at the lower boundary of the thermally active layer of bottom sediment
'500495' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 190 ;
	}

#paramId: 500496
#Mean temperature of the water column
'500496' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500497
#Mixed-layer temperature
'500497' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500498
#Bottom temperature (temperature at the water-bottom sediment interface)
'500498' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500499
#Mixed-layer depth
'500499' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 500500
#Shape factor with respect to the temperature profile in the thermocline
'500500' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500501
#Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)
'500501' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500502
#Sediment thickness of the upper layer of bottom sediments
'500502' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 500503
#Icing Base (hft) - Prognose Icing Degree Composit
'500503' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500504
#Icing Max Base (hft) - Prognose Icing Degree Composit
'500504' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500505
#Icing Max Top (hft) - Prognose Icing Degree Composit
'500505' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500506
#Icing Top (hft) - Prognose Icing Degree Composit
'500506' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500507
#Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Degree Composit
'500507' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500508
#Icing Max Code (1=light,2=moderate,3=severe) - Prognose Icing Degree Composit
'500508' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500509
#Icing Base (hft) - Prognose Icing Scenario Composit
'500509' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500510
#Icing Signifikant Base (hft) - Prognose Icing Scenario Composit
'500510' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500511
#Icing Signifikant Top (hft) - Prognose Icing Scenario Composit
'500511' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500512
#Icing Top (hft) - Prognose Icing Scenario Composit
'500512' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500513
#Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Scenario Composit
'500513' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500514
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Prognose Icing Scenario Composit
'500514' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500515
#Icing Base (hft) - Diagnose Icing Degree Composit
'500515' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500516
#Icing Max Base (hft) - Diagnose Icing Degree Composit
'500516' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500517
#Icing Max Top (hft) - Diagnose Icing Degree Composit
'500517' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500518
#Icing Top (hft) - Diagnose Icing Degree Composit
'500518' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500519
#Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Degree Composit
'500519' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500520
#Icing Max Code (1=light,2=moderate,3=severe) - Diagnose Icing Degree Composit
'500520' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500521
#Icing Base (hft) - Diagnose Icing Scenario Composit
'500521' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500522
#Icing Signifikant Base (hft) - Diagnose Icing Scenario Composit
'500522' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500523
#Icing Signifikant Top (hft) - Diagnose Icing Scenario Composit
'500523' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500524
#Icing Top (hft) - Diagnose Icing Scenario Composit
'500524' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500525
#Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Scenario Composit
'500525' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500526
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Diagnose Icing Scenario Composit
'500526' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500527
#Prognose Icing Degree Code (1=light,2=moderate,3=severe)
'500527' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500528
#Prognose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'500528' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500529
#Diagnose Icing Degree Code (1=light,2=moderate,3=severe)
'500529' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500530
#Diagnose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'500530' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500531
#current weather (symbol number: 0..9)
'500531' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 205 ;
	}

#paramId: 500541
#relative vorticity,U-component
'500541' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500542
#relative vorticity,V-component
'500542' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500550
#Potentielle Vorticity (auf Druckflaechen, nicht isentrop)
'500550' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500551
#geostrophische Vorticity
'500551' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500552
#Forcing rechte Seite Omegagleichung
'500552' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500553
#Q-Vektor X-Komponente (geostrophisch)
'500553' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500554
#Q-Vektor Y-Komponente (geostrophisch)
'500554' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500555
#Divergenz Q (geostrophisch)
'500555' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500556
#Q-Vektor senkrecht zu d. Isothermen (geostrophisch)
'500556' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500557
#Q-Vektor parallel zu d. Isothermen (geostrophisch)
'500557' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500558
#Divergenz Qn geostrophisch
'500558' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 500559
#Divergenz Qs geostrophisch
'500559' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500560
#Frontogenesefunktion
'500560' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 500562
#Divergenz
'500562' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500563
#Q-Vektor parallel zu den Isothermen
'500563' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500564
#Divergenz Qn
'500564' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 500565
#Divergenz Qs
'500565' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500566
#Frontogenesis function
'500566' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 128 ;
	}

#paramId: 500567
#Clear Air Turbulence Index
'500567' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 146 ;
	}

#paramId: 500570
#dry convection top index
'500570' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500571
#- FE1 I128A[AMP]ROUTI von 199809 bis 199905
'500571' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500572
#tidal tendencies
'500572' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500573
#Sea surface temperature interpolated in time in C
'500573' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500574
#Logarithm of Pressure
'500574' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500575
#3 hour pressure change
'500575' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500576
#covariance of soil moisture content (0-10)
'500576' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	}

#paramId: 500585
#Eddy Dissipation Rate
'500585' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500586
#Ellrod Index
'500586' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500592
#Geopotential height
'500592' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500600
#Prob Windboeen > 25 kn
'500600' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500601
#Prob Windboeen > 27 kn
'500601' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500602
#Prob Sturmboeen > 33 kn
'500602' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500603
#Prob Sturmboeen > 40 kn
'500603' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500604
#Prob Schwere Sturmboeen > 47 kn
'500604' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500605
#Prob Orkanartige Boeen > 55 kn
'500605' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500606
#Prob Orkanboeen > 63 kn
'500606' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500607
#Prob Oberoertliche Orkanboeen > 75 kn
'500607' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500608
#Prob Starkregen > 10 mm
'500608' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500609
#Prob Heftiger Starkregen > 25 mm
'500609' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500610
#Prob Extrem Heftiger Starkregen > 50 mm
'500610' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500611
#Prob Leichter Schneefall > 0,1 mm
'500611' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500612
#Prob Leichter Schneefall > 0,1 cm
'500612' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500613
#Prob Leichter Schneefall > 0,5 cm
'500613' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500614
#Prob Leichter Schneefall > 1 cm
'500614' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500615
#Prob Schneefall > 5 cm
'500615' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500616
#Prob Starker Schneefall > 10 cm
'500616' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500617
#Prob Extrem starker Schneefall > 25 cm
'500617' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500618
#Prob Frost
'500618' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500619
#Prob Strenger Frost
'500619' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 500620
#Prob Gewitter
'500620' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500621
#Prob Starkes Gewitter
'500621' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 500622
#Prob Schweres Gewitter
'500622' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 500623
#Prob Dauerregen
'500623' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 500624
#Prob Ergiebiger Dauerregen
'500624' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 500625
#Prob Extrem ergiebiger Dauerregen
'500625' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500626
#Prob Schneeverwehung
'500626' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 500627
#Prob Starke Schneeverwehung
'500627' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500628
#Prob Glaette
'500628' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500629
#Prob oertlich Glatteis
'500629' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500630
#Prob Glatteis
'500630' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500631
#Prob Nebel (ueberoertl. Sichtweite < 150 m)
'500631' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500632
#Prob Tauwetter
'500632' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500633
#Prob Starkes Tauwetter
'500633' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500634
#wake-production of TKE due to sub grid scale orography
'500634' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 155 ;
	}

#paramId: 500635
#shear-production of TKE due to separated horizontal shear modes
'500635' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 156 ;
	}

#paramId: 500636
#buoyancy-production of TKE due to sub grid scale convection
'500636' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500638
#Atmospheric Resistance
'500638' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500639
#Height of thermals above MSL
'500639' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500640
#mass concentration of dust (minimum mode)
'500640' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500643
#mass concentration of dust (medium mode)
'500643' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500644
#mass concentration of dust (maximum mode)
'500644' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500645
#number concentration of dust (minimum mode)
'500645' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500646
#number concentration of dust (medium mode)
'500646' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 500647
#number concentration of dust (maximum mode)
'500647' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500648
#mass concentration of dust (sum of all modes)
'500648' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 251 ;
	}

#paramId: 500649
#number concentration of dust (sum of all modes)
'500649' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 252 ;
	}

#paramId: 500650
#DUMMY_1
'500650' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500651
#DUMMY_2
'500651' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500652
#DUMMY_3
'500652' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500654
#DUMMY_4
'500654' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500655
#DUMMY_5
'500655' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500656
#DUMMY_6
'500656' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500657
#DUMMY_7
'500657' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500658
#DUMMY_8
'500658' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500659
#DUMMY_9
'500659' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500660
#DUMMY_10
'500660' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500661
#DUMMY_11
'500661' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500662
#DUMMY_12
'500662' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500663
#DUMMY_13
'500663' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500664
#DUMMY_14
'500664' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500665
#DUMMY_15
'500665' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500666
#DUMMY_16
'500666' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500667
#DUMMY_17
'500667' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500668
#DUMMY_18
'500668' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500669
#DUMMY_19
'500669' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500670
#DUMMY_20
'500670' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 500671
#DUMMY_21
'500671' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500672
#DUMMY_22
'500672' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 500673
#DUMMY_23
'500673' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 500674
#DUMMY_24
'500674' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 500675
#DUMMY_25
'500675' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 500676
#DUMMY_26
'500676' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500677
#DUMMY_27
'500677' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 500678
#DUMMY_28
'500678' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500679
#DUMMY_29
'500679' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500680
#DUMMY_30
'500680' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500681
#DUMMY_31
'500681' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500682
#DUMMY_32
'500682' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500683
#DUMMY_33
'500683' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500684
#DUMMY_34
'500684' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500685
#DUMMY_35
'500685' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500686
#DUMMY_36
'500686' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 500687
#DUMMY_37
'500687' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 500688
#DUMMY_38
'500688' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 500689
#DUMMY_39
'500689' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500690
#DUMMY_40
'500690' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500691
#DUMMY_41
'500691' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500692
#DUMMY_42
'500692' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500693
#DUMMY_43
'500693' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500694
#DUMMY_44
'500694' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500695
#DUMMY_45
'500695' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 500696
#DUMMY_46
'500696' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 500697
#DUMMY_47
'500697' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 500698
#DUMMY_48
'500698' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 500699
#DUMMY_49
'500699' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 500700
#DUMMY_50
'500700' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 500701
#DUMMY_51
'500701' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500702
#DUMMY_52
'500702' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500703
#DUMMY_53
'500703' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 500704
#DUMMY_54
'500704' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 500705
#DUMMY_55
'500705' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 500706
#DUMMY_56
'500706' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 500707
#DUMMY_57
'500707' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500708
#DUMMY_58
'500708' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500709
#DUMMY_59
'500709' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 500710
#DUMMY_60
'500710' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 500711
#DUMMY_61
'500711' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500712
#DUMMY_62
'500712' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 500713
#DUMMY_63
'500713' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 500714
#DUMMY_64
'500714' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 500715
#DUMMY_65
'500715' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500716
#DUMMY_66
'500716' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 500717
#DUMMY_67
'500717' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 500718
#DUMMY_68
'500718' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 500719
#DUMMY_69
'500719' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500720
#DUMMY_70
'500720' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500721
#DUMMY_71
'500721' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500722
#DUMMY_72
'500722' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500723
#DUMMY_73
'500723' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 500724
#DUMMY_74
'500724' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500725
#DUMMY_75
'500725' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500726
#DUMMY_76
'500726' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500727
#DUMMY_77
'500727' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 500728
#DUMMY_78
'500728' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500729
#DUMMY_79
'500729' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500730
#DUMMY_80
'500730' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 500731
#DUMMY_81
'500731' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 500732
#DUMMY_82
'500732' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 500733
#DUMMY_83
'500733' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500734
#DUMMY_84
'500734' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500735
#DUMMY_85
'500735' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 500736
#DUMMY_86
'500736' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 500737
#DUMMY_87
'500737' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 500738
#DUMMY_88
'500738' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 500739
#DUMMY_89
'500739' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500740
#DUMMY_90
'500740' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500741
#DUMMY_91
'500741' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500742
#DUMMY_92
'500742' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500743
#DUMMY_93
'500743' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500744
#DUMMY_94
'500744' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 500745
#DUMMY_95
'500745' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 500746
#DUMMY_96
'500746' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 500747
#DUMMY_97
'500747' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 500748
#DUMMY_98
'500748' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 500749
#DUMMY_99
'500749' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500750
#DUMMY_100
'500750' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500751
#DUMMY_101
'500751' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500752
#DUMMY_102
'500752' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500753
#DUMMY_103
'500753' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500754
#DUMMY_104
'500754' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500755
#DUMMY_105
'500755' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500756
#DUMMY_106
'500756' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 500757
#DUMMY_107
'500757' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 107 ;
	}

#paramId: 500758
#DUMMY_108
'500758' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 108 ;
	}

#paramId: 500759
#DUMMY_109
'500759' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 500760
#DUMMY_110
'500760' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 500761
#DUMMY_111
'500761' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500762
#DUMMY_112
'500762' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500763
#DUMMY_113
'500763' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500764
#DUMMY_114
'500764' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500765
#DUMMY_115
'500765' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500766
#DUMMY_116
'500766' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 500767
#DUMMY_117
'500767' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500768
#DUMMY_118
'500768' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 500769
#DUMMY_119
'500769' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500770
#DUMMY_120
'500770' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 500771
#DUMMY_121
'500771' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 500772
#DUMMY_122
'500772' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500773
#DUMMY_123
'500773' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500774
#DUMMY_124
'500774' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500775
#DUMMY_125
'500775' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500776
#DUMMY_126
'500776' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 500777
#DUMMY_127
'500777' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500778
#DUMMY_128
'500778' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 128 ;
	}

#paramId: 500779
#DUMMY_129
'500779' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 500780
#DUMMY_130
'500780' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 130 ;
	}

#paramId: 500781
#DUMMY_131
'500781' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500782
#DUMMY_132
'500782' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500783
#DUMMY_133
'500783' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500784
#DUMMY_134
'500784' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500785
#DUMMY_135
'500785' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 135 ;
	}

#paramId: 500786
#DUMMY_136
'500786' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 136 ;
	}

#paramId: 500787
#DUMMY_137
'500787' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 137 ;
	}

#paramId: 500788
#DUMMY_138
'500788' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 500789
#DUMMY_139
'500789' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500790
#DUMMY_140
'500790' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 500791
#DUMMY_141
'500791' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 141 ;
	}

#paramId: 500792
#DUMMY_142
'500792' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 142 ;
	}

#paramId: 500793
#DUMMY_143
'500793' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 143 ;
	}

#paramId: 500794
#DUMMY_144
'500794' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 144 ;
	}

#paramId: 500795
#DUMMY_145
'500795' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 145 ;
	}

#paramId: 500796
#DUMMY_146
'500796' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 146 ;
	}

#paramId: 500797
#DUMMY_147
'500797' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 147 ;
	}

#paramId: 500798
#DUMMY_148
'500798' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 500799
#DUMMY_149
'500799' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 500800
#DUMMY_150
'500800' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 150 ;
	}

#paramId: 500801
#DUMMY_151
'500801' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 500802
#DUMMY_152
'500802' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 500803
#DUMMY_153
'500803' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 153 ;
	}

#paramId: 500804
#DUMMY_154
'500804' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500805
#DUMMY_155
'500805' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 155 ;
	}

#paramId: 500806
#DUMMY_156
'500806' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 156 ;
	}

#paramId: 500807
#DUMMY_157
'500807' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500808
#DUMMY_158
'500808' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 158 ;
	}

#paramId: 500809
#DUMMY_159
'500809' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 159 ;
	}

#paramId: 500810
#DUMMY_160
'500810' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 160 ;
	}

#paramId: 500811
#DUMMY_161
'500811' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 161 ;
	}

#paramId: 500812
#DUMMY_162
'500812' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 162 ;
	}

#paramId: 500813
#DUMMY_163
'500813' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 163 ;
	}

#paramId: 500814
#DUMMY_164
'500814' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 164 ;
	}

#paramId: 500815
#DUMMY_165
'500815' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 165 ;
	}

#paramId: 500816
#DUMMY_166
'500816' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 166 ;
	}

#paramId: 500817
#DUMMY_167
'500817' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 167 ;
	}

#paramId: 500818
#DUMMY_168
'500818' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 168 ;
	}

#paramId: 500819
#DUMMY_169
'500819' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 169 ;
	}

#paramId: 500820
#DUMMY_170
'500820' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 170 ;
	}

#paramId: 500821
#DUMMY_171
'500821' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 171 ;
	}

#paramId: 500822
#DUMMY_172
'500822' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 172 ;
	}

#paramId: 500823
#DUMMY_173
'500823' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 173 ;
	}

#paramId: 500824
#DUMMY_174
'500824' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 174 ;
	}

#paramId: 500825
#DUMMY_175
'500825' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 175 ;
	}

#paramId: 500826
#DUMMY_176
'500826' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 176 ;
	}

#paramId: 500827
#DUMMY_177
'500827' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 177 ;
	}

#paramId: 500828
#DUMMY_178
'500828' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 178 ;
	}

#paramId: 500829
#DUMMY_179
'500829' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 179 ;
	}

#paramId: 500830
#DUMMY_180
'500830' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 180 ;
	}

#paramId: 500831
#DUMMY_181
'500831' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 181 ;
	}

#paramId: 500832
#DUMMY_182
'500832' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 182 ;
	}

#paramId: 500833
#DUMMY_183
'500833' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 183 ;
	}

#paramId: 500834
#DUMMY_184
'500834' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 184 ;
	}

#paramId: 500835
#DUMMY_185
'500835' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 185 ;
	}

#paramId: 500836
#DUMMY_186
'500836' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 186 ;
	}

#paramId: 500837
#DUMMY_187
'500837' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 187 ;
	}

#paramId: 500838
#DUMMY_188
'500838' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 188 ;
	}

#paramId: 500839
#DUMMY_189
'500839' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 189 ;
	}

#paramId: 500840
#DUMMY_190
'500840' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 190 ;
	}

#paramId: 500841
#DUMMY_191
'500841' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500842
#DUMMY_192
'500842' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500843
#DUMMY_193
'500843' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500844
#DUMMY_194
'500844' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500845
#DUMMY_195
'500845' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 195 ;
	}

#paramId: 500846
#DUMMY_196
'500846' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500847
#DUMMY_197
'500847' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500848
#DUMMY_198
'500848' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500849
#DUMMY_199
'500849' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500850
#DUMMY_200
'500850' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500851
#DUMMY_201
'500851' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 201 ;
	}

#paramId: 500852
#DUMMY_202
'500852' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 202 ;
	}

#paramId: 500853
#DUMMY_203
'500853' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500854
#DUMMY_204
'500854' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500855
#DUMMY_205
'500855' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 205 ;
	}

#paramId: 500856
#DUMMY_206
'500856' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 206 ;
	}

#paramId: 500857
#DUMMY_207
'500857' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 500858
#DUMMY_208
'500858' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 208 ;
	}

#paramId: 500859
#DUMMY_209
'500859' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 209 ;
	}

#paramId: 500860
#DUMMY_210
'500860' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 210 ;
	}

#paramId: 500861
#DUMMY_211
'500861' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500862
#DUMMY_212
'500862' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500863
#DUMMY_213
'500863' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500864
#DUMMY_214
'500864' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 214 ;
	}

#paramId: 500865
#DUMMY_215
'500865' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500866
#DUMMY_216
'500866' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 216 ;
	}

#paramId: 500867
#DUMMY_217
'500867' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 217 ;
	}

#paramId: 500868
#DUMMY_218
'500868' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 218 ;
	}

#paramId: 500869
#DUMMY_219
'500869' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 219 ;
	}

#paramId: 500870
#DUMMY_220
'500870' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 220 ;
	}

#paramId: 500871
#DUMMY_221
'500871' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 221 ;
	}

#paramId: 500872
#DUMMY_222
'500872' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 222 ;
	}

#paramId: 500873
#DUMMY_223
'500873' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 223 ;
	}

#paramId: 500874
#DUMMY_224
'500874' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 224 ;
	}

#paramId: 500875
#DUMMY_225
'500875' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 225 ;
	}

#paramId: 500876
#DUMMY_226
'500876' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 226 ;
	}

#paramId: 500877
#DUMMY_227
'500877' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 227 ;
	}

#paramId: 500878
#DUMMY_228
'500878' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 228 ;
	}

#paramId: 500879
#DUMMY_229
'500879' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 229 ;
	}

#paramId: 500880
#DUMMY_230
'500880' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 230 ;
	}

#paramId: 500881
#DUMMY_231
'500881' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500882
#DUMMY_232
'500882' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500883
#DUMMY_233
'500883' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500884
#DUMMY_234
'500884' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 234 ;
	}

#paramId: 500885
#DUMMY_235
'500885' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 235 ;
	}

#paramId: 500886
#DUMMY_236
'500886' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500887
#DUMMY_237
'500887' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 237 ;
	}

#paramId: 500888
#DUMMY_238
'500888' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 238 ;
	}

#paramId: 500889
#DUMMY_239
'500889' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 239 ;
	}

#paramId: 500890
#DUMMY_240
'500890' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 240 ;
	}

#paramId: 500891
#DUMMY_241
'500891' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500892
#DUMMY_242
'500892' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 242 ;
	}

#paramId: 500893
#DUMMY_243
'500893' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500894
#DUMMY_244
'500894' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 244 ;
	}

#paramId: 500895
#DUMMY_245
'500895' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 245 ;
	}

#paramId: 500896
#DUMMY_246
'500896' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 246 ;
	}

#paramId: 500897
#DUMMY_247
'500897' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 247 ;
	}

#paramId: 500898
#DUMMY_248
'500898' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 248 ;
	}

#paramId: 500899
#DUMMY_249
'500899' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 249 ;
	}

#paramId: 500900
#DUMMY_250
'500900' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 250 ;
	}

#paramId: 500901
#DUMMY_251
'500901' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 251 ;
	}

#paramId: 500902
#DUMMY_252
'500902' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 252 ;
	}

#paramId: 500903
#DUMMY_253
'500903' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 253 ;
	}

#paramId: 500904
#DUMMY_254
'500904' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 254 ;
	}

#paramId: 502307
#Albedo - diffusive solar - time average (0.3 - 5.0 m-6)
'502307' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 129 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 502308
#Albedo - diffusive solar (0.3 - 5.0 m-6)
'502308' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 502336
#Skin temperature
'502336' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502339
#Downward direct short wave radiation flux
'502339' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502796
#Precipitation
'502796' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 503049
#Eddy dissipitation rate of TKE
'503049' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 503061
#Downward diffusive short wave radiation flux at surface ( mean over forecast time)
'503061' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503062
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'503062' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503065
#u-momentum flux due to SSO-effects
'503065' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 503066
#v-momentum flux due to SSO-effects
'503066' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 503068
#precipitation, qualified,BRD
'503068' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 503069
#precipitation,BRD
'503069' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 503070
#precipitation phase,BRD
'503070' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 503071
#hail flag,BRD
'503071' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 503072
#snow rate,BRD
'503072' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 503073
#snow rate, qualified,BRD
'503073' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 503076
#Gravity wave dissipation
'503076' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 503078
#relative humidity over mixed phase
'503078' = {
	 table2Version = 250 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 503082
#Friction Velocity
'503082' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 503134
#Downward long-wave radiation flux
'503134' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 503135
#Downward long-wave radiation flux avg
'503135' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 503136
#Downward long-wave radiation flux accum
'503136' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 503142
#Lightning Potential Index
'503142' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 503286
#Impervious (paved or sealed) surface fraction
'503286' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 503287
#Antropogenic heat flux (e.g. urban heating, traffic)
'503287' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 503325
#Lightning Potential Index
'503325' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 503341
#Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)
'503341' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 35 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503342
#Maximum rotation amplitude (positive or negative)  (over given time interval and column)
'503342' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 36 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503343
#Maximum updraft track (over given time interval and column)
'503343' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 37 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503344
#Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)
'503344' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 49 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503345
#Maximum total-column integrated condensed  water (over given time interval)
'503345' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 48 ;
	 indicatorOfTypeOfLevel = 200 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503346
#Composite reflectivity - observation
'503346' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 235 ;
	}

#paramId: 503347
#Composite reflectivity - forecast (simulation)
'503347' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 234 ;
	}

#paramId: 503348
#Maximum of Lightning Potential Index (over given time interval)
'503348' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503349
#Maximum reflectivity track (over given time interval and entire atmosphere)
'503349' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503421
#Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present
'503421' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 503422
#Echotop-height: largest height where radar reflectivity above a threshold is present
'503422' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 503425
#Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)
'503425' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 39 ;
	}

